##########################################################################
#Marx et al. in review
#samc example with panthers
##########################################################################


#load packages
library(raster)           #for raster covariate data; version 2.6-7 used
library(rgdal)            #for reading different types of GIS files; version 1.3-4 used
library(rgeos)            #for centroids of polygons; version 0.3-28 used
library(samc)             #for samc; version 1.0 used


#------------------------------------#
#Step 1: Data preparation
#------------------------------------#

#load files
cost_panther <- raster("cost_panther")
mort_panther <- raster("mort_panther")
source <- readOGR("source_panther.shp")

#inspect projections
projection(cost_panther)
projection(mort_panther) 
projection(source) 

#plot
plot(cost_panther)
plot(mort_panther)
plot(source, add = T)

#inspect
ncell(cost_panther)
res(cost_panther)

#create source raster map-------------

#get the centroids of source polygons
source_centroids <- gCentroid(source, byid = TRUE)

#inspect
source_centroids@coords
source_centroids@coords[1,]               #x,y of first site

#rasterize to get occ map
source_raster <- rasterize(x = source_centroids, y = cost_panther, field = 1, background = 0)

#compare rasters: same res/extent. 
compareRaster(cost_panther, source_raster)

#compare with check function
check(cost_panther, source_raster)
check(cost_panther, mort_panther)

#problem is rasterize() does not retain NA values from our input raster. This can be seen by plotting source_raster

#make NAs consistent
source_raster[is.na(cost_panther[])] <- NA

#compare with check function
check(cost_panther, source_raster)
check(mort_panther, source_raster)

#------------------------------------#
#Step 2: samc creation
#------------------------------------#

#create samc object
Pmatrix <- samc(resistance = cost_panther, absorption = mort_panther,  
                tr_fun = function(x) 1/mean(x), latlon = TRUE)

#inspect
str(Pmatrix)

#------------------------------------#
#Step 3: connectivity analysis
#------------------------------------#

#some long-term connectivity metrics
Dpred_panther <- dispersal(samc = Pmatrix, occ = source_raster)#psi*D: SLOW
Bpred_panther <- mortality(samc = Pmatrix, occ = source_raster)#psi*B
Zpred_panther <- survival(samc = Pmatrix, occ = source_raster)#psi*Z
Zpred_panther_all <- survival(samc = Pmatrix)#Z

#get cell #'s to calculate D for pairs of locations
source_o <- cellFromXY(source_raster, source_centroids@coords[1,])
source_d <- cellFromXY(source_raster, source_centroids@coords[2,])

#calculate D between pairs of locations
Dpred_panther_pair <- dispersal(samc = Pmatrix, origin = source_o, dest = source_d)#D

#some short-term connectivity metrics
Bpred_panther_t100 <- mortality(samc = Pmatrix, occ = source_raster, time = 100)
Bpred_panther_t1000 <- mortality(samc = Pmatrix, occ = source_raster, time = 1000)
Bpred_panther_t10000 <- mortality(samc = Pmatrix, occ = source_raster, time = 10000)

#------------------------------------#
#Step 4: visualize
#------------------------------------#

#create rasters of D and B
Bpanther_map <- map(Pmatrix, Bpred_panther) 
Dpanther_map <- map(Pmatrix, Dpred_panther) 
Zpanther_map <- map(Pmatrix, Zpred_panther_all) 

Bpanther_t100_map <- map(Pmatrix, Bpred_panther_t100) 
Bpanther_t1000_map <- map(Pmatrix, Bpred_panther_t1000) 
Bpanther_t10000_map <- map(Pmatrix, Bpred_panther_t10000) 

#plot
plot(Dpanther_map)
plot(Bpanther_map)



